@@ -1,9 +1,7 @@
 """setting static data"""
 import os
-import sys
 import tempfile
 
-sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 from fake_user_agent import __version__
 
 
